@@ -1,6 +1,6 @@
 """A friendly Python Utilitary RPA."""
 
-__version__ = "1.16"
+__version__ = "1.17"
 __author__ = "Jonathan Bolo"
 
 import os, re, shutil
@@ -28,8 +28,6 @@ from dateutil import tz
 import datetime as dt
 import numpy as np
 
-LEVEL=logging.DEBUG
-
 log=logging.getLogger(__name__)
 log.addHandler(NullHandler())
 
@@ -465,11 +463,10 @@ def config_logging(file_log="", level=logging.DEBUG, console=True):
     #logging file
     if file_log != "":
         fh = logging.FileHandler(file_log)
-        fh.setLevel(level=level)
         fh.setFormatter(formatter)
+        
     if console:
         ch = logging.StreamHandler()
-        ch.setLevel(level=level)
         ch.setFormatter(formatter)
     
     log=logging.getLogger(__name__)
@@ -480,6 +477,8 @@ def config_logging(file_log="", level=logging.DEBUG, console=True):
     if console:
         log.addHandler(ch)
     
+    log.setLevel(level=level)
+    
     log.info("Level log: " + logging.getLevelName(level))
     
     return log
